# Dev Notes

:warning: **Attention:** Hey Reader! Any line that begins like this, is a "comment" that does not impact the rules; these are just left here as notes to myself for later. I've also included :memo: **Developer Notes**, which are more like commentary regarding the design process - these are open for feedback, along with the rules and prose.

# Introduction

:memo: **Developer Note:** Add this to the introduction: Curses and Blessings is a game that focuses largely on exploration and problem-solving. While combat can and does happen, it is not the focus.

:memo: **Developer Note:** If two parties meet, they could have two super smart characters duel via chess to see who climbs the chain first. Reputation can also be a big influence in the game's world.

:question: **TODO:** introductions tend to be written late in development

:question: **TODO:** TOC, glossary of terms - for now, use VSCode's outline panel.

# The Setting

This game's world is centered around Tiere, The Sacred Mountain. Jutting out of an otherwise flat landscape, the mountain can be seen clearly from a great distance in all directions. This has given rise to a multitude of myths and legends centered on the mountain, and has attracted people seeking to climb it for thousands of years.

The history of the mountain is long and storied; the oldest known tales liken it to a great beast emerging from the oceans, walking to its current position and falling asleep. Other, more credible stories tell of ancient and powerful artifacts from long-forgotten kingdoms buried deep within; some of these artifacts are believed to be so powerful, that they could tip the balance of power between nations.

Over time a city named Vorland grew at the mountain's foot; it now houses a thriving culture dedicated to exploring and exploiting the mountain's riches. Foremost among its factions is the Mountaineer's Guild - a branch of the administration that issues licenses to climbers, and handles the processing and sale of recovered artifacts.

It is from here that your game begins.

## Tiere, the Sacred Mountain

:memo: **Developer Notes:** I wonder if I should specify exact altitudes, or just leave it for the player's imagination?

The mountain's slopes are traditionally divided into seven distinct areas, known as "elevations". These are:

* [Vorland, The City Below](#vorland-the-city-below)
* [1st Elevation - Foothills and Forests](#foothills-and-forests)
* [2nd Elevation - Dotted Caves](#dotted-caves)
* [3rd Elevation - Gambler's Bluff](#gamblers-bluff)
* [4th Elevation - Mycelia Jungles](#mycelia-jungles)
* [5th Elevation - Kingdom of Failures](#kingdom-of-failures)
* [6th Elevation - Frigid Plateau](#frigid-plateau)
* [7th Elevation - Chained Apex](#chained-apex)

## Vorland, The City Below

Vorland is a historic resource town that survives by recovering artifacts from the mountain, and selling them across the continent. Built into a valley among the foothills, and marked by the Contrast River, the sight of common-class artifacts is a part of daily life.

Due to its proximity to the 1st Elevation, a prominent stonework wall marks the historical edge of the city's limits; unfortunately, it doesn't always stop strange beasts from wandering the streets at night.

:memo: **Developer Note:** The Contrast River carries fresh water from the 2nd Elevation, and the riverbed is covered in multicolored stones, hence the name. These stones are pretty, but otherwise mundane.

## Foothills and Forests

A dense, but navigable forest that covers the lowest parts of the ascent. The flora here seems to grow unnaturally fast, so any attempt at establishing a permanent road has met with failure. The angle of the slopes averages about 60 degrees, further impeding all but the simplest of construction efforts.

## Dotted Caves

A series of natural and unnatural cuts into the mountain can be found here. The lowest cave openings mark the beginning of the 2nd Elevation. The forests continue up the surface, often obscuring smaller openings, which pose a hazard to those who climb without caution.

The cave systems have yet to be fully explored and mapped due to the dangerous creatures and precarious terrain within; the river that sustains the city below originates from one of the larger openings. The name of this Elevation comes from the unusual rocks and stones found here, which bear an apparent speckled sheen when reflecting light.

## Gambler's Bluff

The 3rd Elevation is a sheer vertical cliff face, which abruptly bursts forth from the ground below. The surface of the bluff is covered with grips and handholds, many of which are no larger than your fingertips. The bluff is pockmarked by narrow tunnels, sometimes called "pigeonholes", dug into the rock face by large birds of prey called "fortner".

Choosing the right pigeonhole to rest in is a gamble, as these are the fortner's nesting places, and choosing an occupied one will result in sudden and violent ejection by the occupants. Many abandoned pigeonholes are connected within the mountain's bulk, and can be traversed, sometimes granting a dark and cramped, but safer route upwards.

:memo: **Developer Note:** The fortner are endemic to the mountain. Up to a third of the pigeonholes are occupied.

## Mycelia Jungles

A vast ecosystem of fungi and other plant matter covers the 4th Elevation. Some of these biological structures are strong enough to support their own weight, and more, while jutting out above the cliff's edge, creating a larger walkable area than what would be expected.

Many creatures endemic to the mountain have evolved to thrive in this high altitude ecosystem, or to venture in for food. While it's possible to consume some of the more benign growths here, the environment is just as likely to consume you in return.

A word of warning: Great care must be taken not to become infected; there are recorded instances of climbers who, after reaching this Elevation and returning to the city below, were totally unperturbed by their bodies being rebuilt or replaced by fungal parasites.

## Kingdom of Failures

High above the clouds, beyond the view of even the best looking glasses, lies the dilapidated remains of past civilizations, Seemingly built into and on top of each other in a dense network of twisting rooms, corridors and bridges. At least three distinct architectural styles have been identified, with many others hinted at having been scrapped for building materials.

Among these ruins live small bands of climbers who, for one reason or another, can't or won't ascend any further. Subsisting on materials grown here or gathered from the jungle, these groups vie for valuable and powerful artifacts buried in the mountain's core.

## Frigid Plateau

The top two Elevations remain hidden in cloud cover at all times; this seemingly unnatural phenomenon also prevents climbers from returning from beyond this point. The only information we've been able to ascertain comes from written reports, secured within rocket-like projectiles, fired through gaps in the cloud barrier by the few brave - or suicidal - souls that enter.

According to the reports, the already cold air becomes frigid, plant life vanishes, and snow drifts hide deep crevasses that swallow people whole.

The most notable feature of this Elevation has only a handful of reliable accounts within the last four centuries - the peak of the mountain has been sliced off, as if by a blade - the exposed rock is smooth to the touch, and seems to extend from one side of the plateau to the other.

## Chained Apex

Visibility on the plateau is poor to non-existent due to cloud cover and snow storms. Among those that wander here, only a lucky few have managed to find the chains - massive metallic structures resembling links in a chain, with one end reaching into the heavens, and the other embedded deep into the rock below.

These chains, measured at two arm spans thick, seem to move over time, as though whatever they tether to the mountain is drifting with the winds. While attempts at climbing them have reportedly been made, no news of success or failure has ever reached the city below.

# Character Creation

:memo: **Developer Note:** I am deliberately leaving the player characters' backgrounds as blank slates for the time being, as focusing on the core mechanics comes first. This may be expanded more in later iterations.

When playing this game, each player adopts the identity of a climber. Each climber has a past, a reason to be here, and an ultimate goal. What these are is up to the player's imagination.

When you begin your campaign, each character begins with four core attributes, some initial skill points, and a beginner's pack to get you going.

## Core Attributes

Each character begins with a set of four attributes, called the Core Attributes. An "attribute" is simply the name of a value belonging to your character - more attributes can be gained, and existing ones improved as you progress play. The current value of an attribute can be reduced by various means, or restored to its maximum value, usually by resting.

The Core Attributes are:

| Name | Value | Description |
| --- | :---: | --- |
| Health | 10/10 | Representing your physical wellness, and is depleted by injuries. |
| Stamina | 10/10 | The amount of energy you have, which can be spent to perform strenuous tasks. |
| Fortitude | 10/10 | How resistant you are to the negative effects of climbing, mountain sickness, and other environmental effects. |
| Obsession | 10/10 | Represents your fixation with the mountain, and how well you can use artifacts. |

Each of the core attributes begins at 10/10 (current/maximum); any additional attributes that you don't have yet are considered to be 0/0.

## Initial Skill Points

When building a new character, you begin with 20 unallocated skill points, with more earned as you play. You can spend these while resting to buy new skills, or level up existing skills; any skills you don't have are considered level 0.

To buy a new skill or level up an existing one, you must first meet the listed prerequisites (including any previous levels), and spend skill points equal to the new level. (e.g. To buy a skill at level 4, you must spend a total of 10 skill points.) Unspent skill points can be saved for later.

There is an additional restriction during character creation; before your character begins their first ascent, they are limited to a maximum of 5 skills. After they begin, this restriction is immediately removed.

## Beginner's Pack

Finally, after creating a new character, they begin with a set of standard issue items granted by the Mountaineer's Guild, including casual clothes, climbing clothes, climbing gloves, solid shoes and a basic hard hat - and most importantly, a basic climbing bag with a capacity of 10 item slots.

The local currency is a small copper coin called an "az", ten of which makes 1 silver "denaz". Each character begins the game with 100az, and can buy extra items from the markets. A full list of items can be found in [Common Items For Purchase](#common-items-for-purchase).

:memo: **Developer Note:** The limited pack space is intended to encourage using consumable items. It also doubles as an interesting choice for the player.

:memo: **Developer Note:** Copper vs. silver coins, as well as other coins from across the continent, are supposed to show how widely people travel to climb the mountain. Some coins in circulation are more valuable in some places than others. For now though, let's keep it simple, with only one currently value, and revisit it later.

# Core Gameplay

The core gameplay of Curses & Blessings is a combination of roleplay scenarios, combat encounters, and skill challenges.

:memo: **Developer Note:** Critical Ranges and Limit Breaks (or bloodied status) are an interesting idea that I toyed with previously, and I do plan on returning to it to see how well they work, once the core rules have ossified.

## Roleplay Scenarios

:question: **TODO:** Detail this - for now, the first play testers know what RP is.

## Skill Challenges

At certain points during the campaign, you will be presented with an obstacle or series of obstacles that requires rolling a d20, and scoring equal or above a certain target value - these are called "Skill Challenges". When performing a Skill Challenge, you may select a skill your character knows that could reasonably contribute towards overcoming that obstacle; either adding the current level of that skill to your roll, or using some listed effect.

On a success, you overcome whatever task you were attempting; on a failure, you lose your choice of either one point of Stamina, or one point from that skill's linked attribute. You cannot use a skill if the linked attribute has already been reduced to 0.

When you fail a Skill Challenge, you may choose to "exert" your character once by spending one point of Stamina to re-roll that attempt - if you do, you must take the new result. If your Stamina (or Fortitude) ever reaches 0 (either by accident or deliberately), you become [Fatigued](#resting-and-fatigue).

:question: **TODO:** Contested challenge: Highest roll? can extert.

## Combat Encounters

:memo: **Developer Note:** Consider advantage & disadvantage.

When you find yourself fending off an attacker, or as an attacker, all participating creatures are said to be in combat. Combat is broken down into a series of rounds, during which each combatant will have the opportunity to act.

At the beginning of each round, all combatants must roll a d20 to determine their turn order, re-rolling to break ties. Then, starting from the first combatant in the turn order, they may either attack with a melee or ranged weapon, maneuver around the environment for a better vantage point, or they may attempt to flee the battle.

If attacking a target, you must first perform a hit roll by rolling a d20, with the target's current Fortitude as the target value. On a success, you may perform a wound roll by rolling dice based on the weapon or item you are using (attacking while unarmed has a wound roll of 1d6).

When you succeed a hit roll, if you rolled a 20 (the maximum value), this is called a critical hit. Unless the effects of a critical hit are listed for the weapon or item you used, the damage dealt by this attack is doubled. When you fail a hit roll, you may choose to "exert" your character once by spending one point of Stamina to re-roll that attempt - if you do, you must take the new result.

The damage dealt by the wound roll is subtracted from the target's Health, and the target's Fortitude is reduced by 1. Just as with Skill Challenges, if a combatant's Stamina or Fortitude ever reaches 0, they become [Fatigued](#resting-and-fatigue). Likewise, if their Health reaches 0, they [die](#dying-and-death).

If you decide to maneuver around the environment on your turn, you can position yourself somewhere that is easier to attack from next round, or places you somewhere out of danger. Sometimes, you may even be able to escape from combat, while abandoning your party members.

## Climbing

Climbing such an immense mountain is no small task. Many people can dedicate their lives to mountaineering, and still not have explored the entirety of even the lower elevations. Add to that, the many dangers and challenges encountered, and it's easy to see why only the bravest - or craziest - are up to the challenge.

Some well-worn pathways are relatively easier to traverse, taking only a set amount of time, while other uncharted paths will present unpredictable and sometimes insurmountable obstacles.

If you choose to follow the established paths, the time taken on each elevation is as follows:

* 1st Elevation - 1 Day
* 2nd Elevation - 2 Days
* 3rd Elevation - 4 Days

For the 3rd Elevation specifically, there are no permanent outposts or resting places, nor are there members of the Mountaineering Guild to guide you up or down - from this point forward, you are on your own.

When returning from a climb, you may be weighed down by discoveries, or injuries, and are more susceptible to those who would take advantage of you. Thankfully, the outposts on the first and second elevations can act as rest areas, and may sometimes offer assistance for your return, for a price.

:question: **TODO:** Add the price for the assistance.

:memo: **Developer Note:** The outpost leader has a secret task, in addition to assisting climbers who pass by - if an artifact with the capability of destabilizing or destroying the power of the Mountaineering Guild, or of the Mountain itself is found, the leader must, at their discretion, suppress or destroy that artifact.

## Mountain Sickness

It's a well known phenomenon across the continent that climbing mountains can cause various maladies. The lower concentrations of oxygen, as well as the lower pressure inherent to higher altitudes, causes a series of nauseating to debilitating effects.

For Tiere, The Sacred Mountain, be it providence or coincidence, it seems that each elevation aligns with the worsening of symptoms. At the dawn of each day, each player must perform a [skill challenge](#skill-challenges) to avoid mountain sickness, depending on which elevation they've reached:

| Elevation | Target | Effect on Failure |
| --- | --- | --- |
| Foothills | No challenge needed. | - | - |
| Dotted Caves | 12 | Lose 1 Fortitude. |
| Gambler's Bluff | 14 | Lose 1 Fortitude, then you need to spend 1 segment of time recovering before you can continue climbing. |
| Mycelia Jungles | 16 | Lose 1 Fortitude, then make another skill challenge with a target of 16, and on a failure, you become Fatigued. |
| Kingdom of Failures | 16 | Lose 1 Stamina and 1 Fortitude, and all rolls for this day receive a -1 penalty. |
| Frigid Plateau | - | - |
| Chained Apex | - | - |

Multiple skills are available for purchase which alleviate these symptoms, or at a minimum, makes the effects bearable. Other medicinal solutions exist, such as sunberries, which grow across the first five elevations.

:question: **TODO:** Skills that make it easier have a prerequisite like: Reach elevation X and return to the city.

## Resting and Fatigue

Climbing the mountain can be taxing on both the mind and body - if your character's Stamina or Fortitude attributes ever reaches zero, that character becomes Fatigued. While your character has Fatigued condition, any combat damage they deal is reduced by half (rounded up), and any combat damage they receive is doubled.

While on the mountain, if you find a safe location, you may decide to rest. Resting will restore your attributes and allow you to use items, and sleep.

While Fatigued, your attributes will not be restored by resting until the Fatigued status is alleviated. To do this, you must sleep for at least 2 blocks of time (six hours) without a break. Once you are no longer Fatigued, you may continue to rest. If you are not Fatigued, you can restore your attributes by resting for at least 1 block of time (3 hours).

## Dying and Death

Your character's Health attribute represents their physical fitness - as they accumulate injuries or illnesses, their Health attribute will be directly impacted. If your character's Health attribute is ever reduced to 0 or below, they die.

Even before your character's Health drops to 0, some situations my cause potentially debilitating conditions, such as becoming poisoned or losing a limb, requiring some kind of prosthetic to continue.

:memo: **Developer Note:** Poisons and prosthetics are possible future mechanics. I'm also considering other generic conditions like blindness and deafness. Exactly what effect these will have, I haven't decided yet - they may impact more than just your attributes.

## Distances and Measurements

In this game, distances are abstracted, to allow for ease of gameplay - the four ways of determining distance are Touch, Close, Nearby and Far. Anything you are holding or are in contact with is within touching distance. If something is close, then you could touch it with an outstretched arm, or with only one or two steps. Something that is nearby is easily reachable, and would be able to hear you if you spoke. Anything outside this is far away.

Any items, weapons or artifacts that don't list an effective range would generally have a range of touch.

## The Passage of Time

For climbers on the mountain, keeping track of the time of day is important, as different and dangerous creatures may be active at different times.

Rather than following the traditional 24-hour system, one full day on the mountain is divided into 8 blocks of roughly equal size, usually depicted as a circle divided into 8 segments. Clockwise from the top are midday, dusk, midnight and dawn, marking the four cardinal points on the circle.

# Common Items For Purchase

For those who live and work in Vorland, the sight of pilgrims, adventurers and fortune seekers is an everyday occurrence. The local coinage is often mixed with coins from across the continent, or may bear markings of old - but they are all welcomed by the city's businesses.

Below is a table of the most commonly purchased mountaineering gear. While not an exhaustive list of what's available, these items can be purchased with very little hassle. Items listed as "Petty" are normally attached to the outside of your pack or to your body, so they don't consume inventory space. Items listed as "Bulky" are larger than normal, so they take two inventory spaces to carry.

| Item | Cost | Description |
| --- | ---: | --- |
| Food Rations | 5az | Dry, dull tasting but nutritious, it's made up of nuts and common fruits, dried and condensed into an easy to hold bar shape. Enough for one meal. |
| Cooking and Cutlery Gear | 30az | Ideal for preparing meals while roughing it, this contains several small pots, cups, multiuse cutlery, and a flimsy stand for a campfire. |
| Sleeping Set | 50az | Bulky. A thin but warm blanket, and a soft but durable mat with a small pillow sewn onto one end. |
| Small Knife and Sheath | 10az | Weapon (2d6), Petty. A small but sharp knife, and a sheath that attaches to a belt. |
| Small Folding Pickaxe | 30az | Weapon (2d6). A small but sturdy pickaxe that can be folded away. |
| Small Compass | 40az | Petty. A small compass, its magnetic needle points north. |
| 10 m Rope | 10az | A good solid length of rope, sold in multiples of 10 meters. Can be tied to a piton embedded in a wall. |
| Piton Bundle | 20az | A spike with a loop on the other end, sold in bundles of three. Each bundle of up to three pitons consumes one inventory slot. |
| Glowstone Lantern | 45az | Produces a moderate amount of light. Usually safe to use, as long as the glowstone within is handled carefully. |
| 2 m Bandages | 10az | Essential for emergencies, it can be used to bind or staunch a wound, or as a makeshift sling for a broken limb. |
| Soothing Salve | 15az | A pale viscous cream derived from a fungus, used for pain relief. Apply no more than once per segment of time to a wound to restore 1d6 Health. Does not heal broken bones or restore lost body parts, 6 uses. |
| Cold Weather Clothes | 1000az | Highly durable warm weather clothing, effectively essential at higher altitudes. Available in various sizes. |
| Sketchbook and Pencil | 25az | A simple but durable notebook, with pages ideal for sketching or taking notes. Comes with a matching pencil. |
| Small Candle Bundle | 20az | A small, portable candle that produces a weak light, but last for a few hours. Comes with a small glowstone to light them. Each bundle of up to ten candles consumes one inventory slot. |

:question: **TODO:** Tie a mechanical bonus to these, where needed

# Artifacts

:question: **TODO:** Empty - We're here for the Phat Lute.

Following your return from a climb, the Mountaineer's Guild has services that you can use to exchange your finds for hard-earned money and skill points. Each artifact lists the reward in its stat block.

As members of the Mountaineering Guild, refusing to exchange recovered artifacts upon return is considered an illegal act, and will lead to immediate dismissal and incarceration. So, unless otherwise permitted, be discreet with the more *interesting* finds.

## Classifications

Each type of artifact falls into one of the following broad classes, which can often dictate how they're handled:

[Common Class](#common-artifacts): There are many examples of this artifact, or it can be easily crafted from an artifact. Their effects are fairly simple or mundane.

[Uncommon Class](#uncommon-artifacts): While not impossible to obtain, uncommon-class artifacts are hard to come by, and sell for high prices. Their effects can vary from moderately impactful, to extremely dangerous or destructive if misused.

[Rare Class](#rare-artifacts): While multiples of some rare-class artifacts do exist, the exact number could be counted on one hand. The sale of these is regulated on a case-by-case basis, as some have the capacity to tip the balance of power between nations.

[Nocturne Class](#nocturne-artifacts): These artifacts, for whatever reason, cannot be recovered or sold by the Mountaineer's Guild. Some are immovable, while others have been bound to an individual's body - the exact circumstances vary.

[Restricted](#restricted-artifacts): This is a special class, reserved only for artifacts that actively cause harm, and are therefore illegal to possess. Being caught in possession of a restricted artifact can come with steep fines and punishments.

## Common Artifacts

**Name: Glowstone**  
Sell Price: 2az each  
Skill Points: 1 each, max 10 per climb  
Carry Slots: 1 per 10 stones  

A kind of semi-precious gemstone which, when a small amount of pressure is applied, produces a bright green glow; excessive pressure can cause an explosion. Since this can be used as a light source that doesn't produce heat, glowstone lanterns can be fashioned from these.

---

**Name: Chillbloom Seeds**  
Sell Price: 40az per Kg  
Skill Points: 2 per Kg  
Carry Slots: 1 per Kg, max 3 slots  

The seeds of a Chillbloom Flower, with heat-absorbing properties. Bags of these seeds are often used to treat swelling or aching limbs. Chillblooms resemble white sunflowers that grow among the canopies in the 1st Elevation.

:question: **TODO:** Add to the herbarium

---

**Name: Soothing Water**  
Sell Price: -  
Skill Points: -  
Carry Slots: 1 per Liter, requires a container  

Some springs within the Dotted Caves contain pools of water with mild restorative properties. Drinking some of this while you rest will grant you a one-use effect to restore 1d6 Health while not in combat. This effect only lasts for 1 day.

:question: **TODO:** Add water bottle to items

---

**Name: Singing Starstone**  
Sell Price: 4az each  
Skill Points: 1 each, max 10 per climb  
Carry Slots: 1 per 10 stones  

A kind of spiritual cousin to glowstones, these odd gems produce a bell-like tone when movement is detected within a hand's distance. The exact tone varies based on its shape, so a small industry of cutting these stones for aesthetic purposes can be found in Vorland.

---

**Name: Unrefined Impact**  
Sell Price: 10az per Kg  
Skill Points: 10 per Kg, max 20 per climb  
Carry Slots: 2 per Kg  

A hard mineral which is surprisingly dense. Useless on its own, but its chemical properties are used in various industries.

## Uncommon Artifacts

**Mental Catalyst**  
Sell Price: 150az per drop  
Skill Points: -  
Carry Slots: 1  

Processed from material gathered from the Mycelia Jungles, a small dose can sharpen your perception and boost your thinking power. However, this sensation is extremely addictive, and can lead to dependence.

When you ingest a drop of the Mental Catalyst, make a Skill Challenge with a target of 14. If you succeed, for the next day, you may spend 1 point of Obsession to roll two dice for skill challenges instead of one, and take the highest.

---

**Mirror Mask**  
Sell Price: 250az  
Skill Points: 15  
Carry Slots: 1  

An ancient mask with a mirror-like surface, it allows the wearer to copy the feats of those they watch until the mask is removed. Extended use may lead to feelings of a loss of identity.

When you watch someone use a skill, you may spend Obsession equal to that skill's level to copy it. You may use that skill until you remove this mask, at which time all copied skills are lost.

If you are wearing the Mirror Mask at the dawn of each day, before you roll to avoid Mountain Sickness, choose a skill you have learned but haven't copied. That skill's level is reduced by 1, to a minimum of 0.

---

**Mountain's Stinger**  
Sell Price: 200az each  
Skill Points: 12  
Carry Slots: 1  

Weapon (1d4). A needle-like object that was once part of a larger weapon. Landing a successful attack with these causes the target to suffer the effects of mountain sickness, as though they failed the skill challenge at their current elevation. This can be applied multiple times.

---

**Dhampir's Appetite**  
Sell Price: 400az each  
Skill Points: 10  
Carry Slots: 1  

Weapon (2d8). An ornate but well-balanced knife. Each time an attack with this weapon deals damage, the user restores 1 Health.

## Rare Artifacts

:question: **TODO:** Empty

## Nocturne Artifacts

:question: **TODO:** Empty

## Restricted Artifacts

:question: **TODO:** Empty

# Skill Point Tables

During your campaign, your characters can learn new skills by allocating unused skill points towards them. Each known skill has a level (starting at 1), the effects of the skill may change drastically depending on the given level. You can only gain a new level of a skill if you meet that skill level's prerequisites as listed, as well as having all previous levels of that skill. To purchase a new level in a skill, allocate unused skill points equal to that level towards that skill.

## Progression Skills

| Name | Prerequisites | Effect |
| --- | --- | --- |
| Health Up | - | Increase your maximum Health attribute by 2 for each level in this skill. |
| Stamina Up | - | Increase your maximum Stamina attribute by 1 for each level in this skill. |
| Fortitude Up | - | Increase your maximum Fortitude attribute by 1 for each level in this skill. |
| Obsession Up | - | Increase your maximum Obsession attribute by 1 for every level in this skill. |

## Survival Skills

| Name | Prerequisites | Effect |
| --- | --- | --- |
| Gathering | - | You know which small plants, fruits and nuts can be safely eaten. If your level in this skill is equal or above your current elevation, you may spend 1 segment of time gathering enough for 1d4+2 people to eat. |
| Identify Poisons | - | You can identify when someone has been poisoned and how. You may perform a skill challenge with a target value of 18, adding your level in this skill to your roll, to identify if food or water has been poisoned and how. |
| Grit Your Teeth | - | If half or more of your party has been reduced to half their Health or less, you may add +2 to your attack and damage rolls. If your level in this skill is 4 or more, add +5 instead. |

## Combat Skills

| Name | Prerequisites | Effect |
| --- | --- | --- |
| Utilize Poisons | Identify Poisons Level 4 | You may apply poisons to your weapons. If you deal damage with a poisoned weapon, that target becomes poisoned, and loses Health equal to your level in this skill at the beginning of their turn. Multiple instances of poison can't be applied at once; instead the higher poison value takes effect. |
| Honor Dueling | No prior levels in this skill | While not in combat, you may challenge an opponent to a formal duel to settle a dispute. If they accept, no one can interfere until first blood has been drawn. |
| Outnumbered | - | If your party is in combat with more than double its number in enemies, defeating an enemy allows you to attack again. You may use this skill up to its level each turn. |
| Outgunned | Outnumbered Level 3 | If half or more of your party is Fatigued, multiply your damage by the amount of your Fatigued party members. |

## Craft Skills

:question: **TODO:** Empty - "crafts" are more like "professions"; maximum 2 from this category.

## Group Skills

Group skills are unique, in that they are unusable and unobtainable unless everyone in the group allocates the required skill points.

:question: **TODO:** Empty

| Name | Prerequisites | Effect |
| --- | --- | --- |
| Rope Up | - | The party can tie themselves together with a length of rope and climb a cliff face or other dangerous ledge. If anyone fails a skill challenge to prevent themselves from falling, each other person tied to the rope performs a skill challenge with a target value of 12 to save them. If half or more of those saves succeed, the fall is prevented. |
| Battle Cohesion | - | If another ally in combat has this skill, you each gain +1 to attack rolls. If every ally in combat has this skill, you each gain +2 to attack rolls instead. |

# Bestiary

**Ambush Wolf**  
Health: 3  
Stamina: 8  
Fortitude: 12  
Obsession: 5  

Bite: Weapon (1d4). This creature gains +2 to attack rolls if they attacked from a hidden ambush.

Ambush Wolves, with their green mottled coats, blend into the forests of the 1st and 2nd Elevations. While they do venture beyond the bounds of the mountain, their primary hunting method is to disguise themselves in the thick vegetation, and wait for their prey. What makes these beasts truly dangerous is when they hunt in packs of between three and ten, though accounts of several dozen have been reported.

---

**Bandit Monkey**  
Health: 2  
Stamina: 16  
Fortitude: 10  
Obsession: 14  

Rock Throw: Weapon (1d4). This creature can throw a rock or other hard objects at anything nearby.

Mob Rush: When this creature is gathered in groups of 10 or more, they can attack as a group by jumping on their targets, causing confusion distress. They will take this opportunity to steal any desired items they can carry.

Bandit Monkeys are a common sight in the forests and foothills, forming part of the soundscape of the mountain. Due to their proximity to Vorland's outer walls, interactions with these tree-dwelling simians are not uncommon. Their tendency to steal from unsuspecting travellers, either for food or for fun, is a well known trait - their tactics aren't intended to severely harm or kill, and items of little use are often discarded after inspection.

Children's stories often use Bandit Monkeys as main characters, and several notable architectural landmarks bear the images of monkeys at play. Bandit Monkeys have been a part of Vorland's cultural background for many generations, with some superstitions forbidding the harming of them or their homes, lest they retaliate against the city in their thousands.

---

**Dust Ants**  
Health: 2  
Stamina: 10  
Fortitude: 2  
Obsession: 0  

Nibble: Weapon (1d4). This creature attacks by biting with its short but sharp mandibles.

Call The Horde: When this creature senses danger to itself or its nest, it lets out a high ear-splitting screech. Any nearby creatures other than Dust Ants that hear it are deafened for one round of combat. Then, on each round of combat starting with the next, 2d6 more Dust Ants arrive to assist - if you roll 6 or below, this effect ends. Otherwise, repeat this check on the following round. This attack can only be used by the nest once per day.

These insects, being about the size of a small cat, are commonly seen within the winding tunnels of the Dotted Caves. While not truly metallic, their carapaces bear a metallic sheen, with some individuals sharing the patterns of the tunnel walls.

They pose little danger on their own, but each one is capable of calling for help from other members of the nest - when aggrivated, the best strategy to deal with these is to run away before they overwhelm you with sheer numbers.

:memo: **Developer Note:** The name of the Dust Ant is interesting - what does it mean? Are the ants merely specks of dust among many? Are they using some archaic language for them? Or are their excavations destined to one day reduce the mountain to dust?

:memo: **Developer Note:** I want to catch a Dust Ant and name it Hoffman.

---

**Rock Bear**  
Health: 12  
Stamina: 10  
Fortitude: 18  
Obsession: 2  

Paw Swipe: Weapon (1d6). This creature can attack up to two close targets in one turn.

Rock Bears get their name form the rock-like carapace covering their bodies. When they curl up, they can often be mistaken for part of the landscape. Despite their names, they're more closely related to pangolins.

These fearsome creatures are surprisingly docile if left undisturbed, with the exception of early spring, where they're actively rearing their young.

---

**Whiptongue**  
Health: 45  
Stamina: 20  
Fortitude: 20  
Obsession: 3  

Smash: Weapon (1d12). This creature slams a target using it's tongue.

Grab: This creature can wrap its tongue securely around a target, and on a successful skill challenge against the target's Fortitude, it will forcibly pull them into its mouth, trapping them, and causing 1d8 damage each turn. A wrapped or trapped target can escape on a successful skill challenge against the whiptongue's Fortitude.

A strange amalgam of creatures that have been infected by the mycelia Jungles, this gestalt monstrosity has embedded itself deep into the cliff face, and nourishes itself by stretching out and grasping with it's long prehensile tongue.

Observations of this "creature" are difficult due to the length of the appendage, but the external appearance resembles a reddish bulge of flesh in the cliff face, with a diameter of about 1.5 meters. The Whiptongue is immobile, with a root system that stretches an unknown distance into the mountain. Extreme caution is advised.

# Herbarium

:question: **TODO:** Empty

# Appendices

:question: **TODO:** Empty

